ImagesToPaint class

Constructors

ImagesToPaint({required ImageDetails completedLevelImage, required ImageDetails currentLevelImage, required ImageDetails lockedLevelImage, List<BGImage>? bgImages, ImageDetails? startLevelImage, ImageDetails? pathEndImage})

Properties

bgImages → List<BGImage>?
final
completedLevelImage → ImageDetails
final
currentLevelImage → ImageDetails
final
hashCode → int
The hash code for this object.
no setteroverride
lockedLevelImage → ImageDetails
final
pathEndImage → ImageDetails?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLevelImage → ImageDetails?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override